.. _Tutorial2Demo:

==========
Tutorial 2
==========

My new bar plots:

.. report:: Tutorial2.MyDataOneTrack
   :render: interleaved-bar-plot

   My first bar plot - this time as a functor

.. report:: Tutorial2.MyDataTwoTracks
   :render: interleaved-bar-plot

   My new bar plot - two tracks

.. report:: Tutorial2.MyDataTwoTracks
   :render: stacked-bar-plot

   My new bar plot - same data, different renderer
